@@ -407,6 +407,7 @@ class cFreeDiamsInterface(cDrugDataSourceInterface):
 			r'/usr/bin/freediams',
 			r'freediams',
 			r'/Applications/FreeDiams.app/Contents/MacOs/FreeDiams',
+			r'C:\Program Files\FreeDiams\freediams.exe',
 			r'c:\programs\freediams\freediams.exe',
 			r'freediams.exe'
 		])
@@ -962,8 +963,12 @@ class cGelbeListeWindowsInterface(cDrugDataSourceInterface):
 	#--------------------------------------------------------
 	def switch_to_frontend(self, blocking=False, cmd=None):
 
-		# must make sure csv file exists
-		open(self.default_csv_filename, 'wb').close()
+		try:
+			# must make sure csv file exists
+			open(self.default_csv_filename, 'wb').close()
+		except IOError:
+			_log.exception('problem creating GL/MMI <-> GNUmed exchange file')
+			return False
 
 		if cmd is None:
 			cmd = (u'%s %s' % (self.path_to_binary, self.args)) % self.default_csv_filename_arg
@@ -1686,7 +1691,17 @@ def create_substance_intake(pk_substance=None, pk_component=None, preparation=No
 			)
 			RETURNING pk"""
 
-	rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}], return_data = True)
+	try:
+		rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}], return_data = True)
+	except gmPG2.dbapi.InternalError, e:
+		if e.pgerror is None:
+			raise
+		if 'prevent_duplicate_component' in e.pgerror:
+			_log.exception('will not create duplicate substance intake entry')
+			_log.error(e.pgerror)
+			return None
+		raise
+
 	return cSubstanceIntakeEntry(aPK_obj = rows[0][0])
 #------------------------------------------------------------
 def delete_substance_intake(substance=None):
